@@ -25,6 +25,12 @@ class PageContent(content.ModelContent):
 
     panels = (PageHistoryPanel,)
 
+    def get_form_initial_data(self, request):
+        if request is not None and request.user.is_authenticated():
+            return dict(owner=request.user)
+        else:
+            return None
+
     def get_new_url(self):
         return reverse_lazy('new_versioned_page')
 
