@@ -15,7 +15,7 @@ def upload_photos(request):
     for f in request.FILES.getlist("file"):
         obj = Image.objects.create(file=f)
         images = {"filelink": obj.file.url}
-    return HttpResponse(json.dumps(images), mimetype="application/json")
+    return HttpResponse(json.dumps(images), content_type="application/json")
 
 
 @login_required
@@ -24,4 +24,4 @@ def recent_photos(request):
         {"thumb": obj.file.url, "image": obj.file.url}
         for obj in Image.objects.all().order_by("-created")[:20]
     ]
-    return HttpResponse(json.dumps(images), mimetype="application/json")
+    return HttpResponse(json.dumps(images), content_type="application/json")
